# OsensaIMOS

Python module for interfacing with the OSENSA IMOS.

Refer to https://github.com/osensa/osensaimos for source code and examples.

### History
_Release 0.1.0b1:_
* Test release
 
_Release 0.1.1b1:_
* Initial release

_Release 0.1.2b1:_
* Restructure package and add example file

_Release 0.1.3b1:_
* Add stream mode bug fixes and parse logic

